mysql.exceptions.internal.Result_Unbuffered_Error

Package mysql :: Package exceptions :: Module internal :: Class Result_Unbuffered_Error |
[hide private]
[frames] | no frames]

# Class Result_Unbuffered_Error

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              Result_Unbuffered_Error

Attempted to call a method that requires the results to be buffered (stored) locally.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`